@@ -3,8 +3,8 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
-**  including this file, may be copied, modified, propagated, or distributed 
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
 **  except according to the terms described in the LICENSE file.
 */
 
@@ -32,11 +32,11 @@ ControlMethod::toString(ControlMethod::Method method)
   return str;
 }
 
-ControlMethod::Method 
+ControlMethod::Method
 ControlMethod::fromString(QString method)
 {
   if(method == QString("ControlPort"))
     return ControlMethod::Port;
-  else if(method == QString("ControlSocket"))
+  else// if(method == QString("ControlSocket"))
     return ControlMethod::Socket;
 }
