@@ -3,8 +3,8 @@
 **  LICENSE file, found in the top level directory of this distribution. If
 **  you did not receive the LICENSE file with this file, you may obtain it
 **  from the Vidalia source package distributed by the Vidalia Project at
-**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
-**  including this file, may be copied, modified, propagated, or distributed 
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
 **  except according to the terms described in the LICENSE file.
 */
 
@@ -209,6 +209,33 @@ TorControl::disconnect()
     _controlConn->disconnect();
 }
 
+void
+TorControl::getBootstrapPhase()
+{
+  ControlCommand cmd("GETINFO", "status/bootstrap-phase");
+  ControlReply reply;
+  QString str;
+
+  if (!send(cmd, reply, &str)) {
+    return;
+  }
+
+  bool ok;
+  QHash<QString, QString> args;
+  args = string_parse_keyvals(reply.getMessage(), &ok);
+
+  if(!ok)
+    return;
+
+  tc::Severity severity = tc::severityFromString(args.value("status/bootstrap-phase"));
+  BootstrapStatus status
+    = BootstrapStatus(severity,
+                      BootstrapStatus::statusFromString(args.value("TAG")),
+                      args.value("PROGRESS").toInt(),
+                      args.value("SUMMARY"));
+  emit bootstrapStatusChanged(status);
+}
+
 /** Emits a signal that the control socket disconnected from Tor */
 void
 TorControl::onDisconnected()
@@ -309,6 +336,8 @@ TorControl::onAuthenticated()
   /* We want to use extended events in all async events */
   useFeature("EXTENDED_EVENTS");
 
+  getBootstrapPhase();
+
   emit authenticated();
 }
 
@@ -881,7 +910,14 @@ bool
 TorControl::saveConf(QString *errmsg)
 {
   ControlCommand cmd("SAVECONF");
-  return send(cmd, errmsg);
+  bool ret = send(cmd, errmsg);
+
+  if(!ret) {
+    QString err;
+    setConf("__ReloadTorrcOnSIGHUP", "0", &err);
+  }
+
+  return ret;
 }
 
 /** Tells Tor to reset the given configuration keys back to defaults. */
@@ -905,6 +941,20 @@ TorControl::resetConf(QString key, QString *errmsg)
   return resetConf(QStringList() << key, errmsg);
 }
 
+bool
+TorControl::useMicrodescriptors(QString *errmsg)
+{
+  if(!errmsg)
+    errmsg = new QString();
+
+  QString mdres, fetchres;
+  if(!getConf("UseMicrodescriptors", mdres, errmsg))
+    return false;
+  if(!getConf("FetchUselessDescriptors", fetchres, errmsg))
+    return false;
+  return (mdres == "1") or (mdres == "auto" and fetchres == "0");
+}
+
 /** Returns an unparsed router descriptor for the router whose fingerprint
  * matches <b>id</b>. The returned text can later be parsed by the
  * RouterDescriptor class. If <b>id</b> is invalid, then an empty
@@ -912,6 +962,9 @@ TorControl::resetConf(QString key, QString *errmsg)
 QStringList
 TorControl::getRouterDescriptorText(const QString &id, QString *errmsg)
 {
+  if(useMicrodescriptors(errmsg))
+    return getInfo("md/id/" + id, errmsg).toStringList();
+
   return getInfo("desc/id/" + id, errmsg).toStringList();
 }
 
@@ -921,7 +974,7 @@ TorControl::getRouterDescriptorText(const QString &id, QString *errmsg)
 RouterDescriptor
 TorControl::getRouterDescriptor(const QString &id, QString *errmsg)
 {
-  return RouterDescriptor(getRouterDescriptorText(id, errmsg));
+  return RouterDescriptor(getRouterDescriptorText(id, errmsg), useMicrodescriptors());
 }
 
 /** Returns the status of the router whose fingerprint matches <b>id</b>. If
@@ -1098,3 +1151,10 @@ TorControl::ipToCountry(const QHostAddress &ip, QString *errmsg)
   return QString();
 }
 
+/** Takes ownership of the tor process it's communicating to */
+bool
+TorControl::takeOwnership(QString *errmsg)
+{
+  ControlCommand cmd("TAKEOWNERSHIP");
+  return send(cmd, errmsg);
+}
