@@ -3,8 +3,8 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
-**  including this file, may be copied, modified, propagated, or distributed 
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
 **  except according to the terms described in the LICENSE file.
 */
 
@@ -32,7 +32,6 @@
 #include <QShortcut>
 #include <QTranslator>
 #include <QLibraryInfo>
-#include <QSslSocket>
 
 #ifdef Q_OS_MACX
 #include <Carbon/Carbon.h>
@@ -115,7 +114,7 @@ Vidalia::Vidalia(QStringList args, int &argc, char **argv)
     if (!_args.contains(ARG_LOGFILE))
       _log.open(stdout);
   }
-  if (!_args.contains(ARG_LOGLEVEL) && 
+  if (!_args.contains(ARG_LOGLEVEL) &&
       !_args.contains(ARG_LOGFILE))
     _log.setLogLevel(Log::Off);
 
@@ -127,16 +126,12 @@ Vidalia::Vidalia(QStringList args, int &argc, char **argv)
   /* Creates a TorControl object, used to talk to Tor. */
   _torControl = new TorControl(TorSettings().getControlMethod());
 
-  /* If we were built with QSslSocket support, then populate the default
-   * CA certificate store. */
-  loadDefaultCaCertificates();
-
 #ifdef USE_MARBLE
   /* Tell Marble where to stash its generated data */
   Marble::MarbleDirs::setMarbleDataPath(dataDirectory());
 
 #ifdef Q_OS_WIN32
-  Marble::MarbleDirs::setMarblePluginPath(vApp->applicationDirPath() 
+  Marble::MarbleDirs::setMarblePluginPath(vApp->applicationDirPath()
                                             + "/plugins/marble");
 #endif
 #endif
@@ -198,7 +193,7 @@ Vidalia::showUsageMessageBox()
 
   out << "Available Options:" << endl;
   out << "<table>";
-  out << trow(tcol("-"ARG_HELP) + 
+  out << trow(tcol("-"ARG_HELP) +
               tcol(tr("Displays this usage message and exits.")));
   out << trow(tcol("-"ARG_RESET) +
               tcol(tr("Resets ALL stored Vidalia settings.")));
@@ -214,12 +209,12 @@ Vidalia::showUsageMessageBox()
   out << trow(tcol("-"ARG_GUISTYLE" &lt;style&gt;") +
               tcol(tr("Sets Vidalia's interface style.") +
                    "<br>[" + QStyleFactory::keys().join("|") + "]"));
-  out << trow(tcol("-"ARG_LANGUAGE" &lt;language&gt;") + 
+  out << trow(tcol("-"ARG_LANGUAGE" &lt;language&gt;") +
               tcol(tr("Sets Vidalia's language.") +
                    "<br>[" + LanguageSupport::languageCodes().join("|") + "]"));
   out << "</table>";
 
-  VMessageBox::information(0, 
+  VMessageBox::information(0,
     tr("Vidalia Usage Information"), usage, VMessageBox::Ok);
 }
 
@@ -480,7 +475,6 @@ err:
     delete vidaliaQtTranslator;
   if (vidaliaTranslator)
     delete vidaliaTranslator;
-  delete vidaliaTranslator;
   return false;
 }
 
@@ -494,7 +488,7 @@ Vidalia::copyDefaultSettingsFile() const
   CFStringRef pathRef;
   const char *path;
 
-  confUrlRef = CFBundleCopyResourceURL(CFBundleGetMainBundle(), 
+  confUrlRef = CFBundleCopyResourceURL(CFBundleGetMainBundle(),
                                        CFSTR("vidalia"), CFSTR("conf"), NULL);
   if (confUrlRef == NULL)
     return;
@@ -517,22 +511,3 @@ Vidalia::copyDefaultSettingsFile() const
 #endif
 }
 
-void
-Vidalia::loadDefaultCaCertificates() const
-{
-  QSslSocket::setDefaultCaCertificates(QList<QSslCertificate>());
-
-  if (! QSslSocket::addDefaultCaCertificates(":/pki/EquifaxSecureCA.crt"))
-    vWarn("Failed to add the Equifax Secure CA certificate to the default CA "
-          "certificate database.");
-  if (! QSslSocket::addDefaultCaCertificates(":/pki/DigiCertCA.crt"))
-    vWarn("Failed to add the DigiCert Global CA certificate to the default CA "
-          "certificate database.");
-  if (! QSslSocket::addDefaultCaCertificates(":/pki/DigiCertAssuredCA.crt"))
-    vWarn("Failed to add the DigiCert Assured CA certificate to the default CA "
-          "certificate database.");
-  if (! QSslSocket::addDefaultCaCertificates(":/pki/DigiCertHighAssuranceCA.crt"))
-    vWarn("Failed to add the DigiCert High Assurance CA certificate to the default CA "
-          "certificate database.");
-}
-
