@@ -3,8 +3,8 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
-**  including this file, may be copied, modified, propagated, or distributed 
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
 **  except according to the terms described in the LICENSE file.
 */
 
@@ -136,7 +136,7 @@ AdvancedPage::save(QString &errmsg)
     if (controlAddress.isNull()) {
       errmsg = tr("'%1' is not a valid IP address.")
                 .arg(ui.lineControlAddress->text());
-      return false; 
+      return false;
     }
     _settings->setControlMethod(ControlMethod::Port);
   } else {
@@ -147,9 +147,9 @@ AdvancedPage::save(QString &errmsg)
     }
     _settings->setControlMethod(ControlMethod::Socket);
   }
-  
+
   /* Validate the selected authentication options */
-  TorSettings::AuthenticationMethod authMethod = 
+  TorSettings::AuthenticationMethod authMethod =
     indexToAuthMethod(ui.cmbAuthMethod->currentIndex());
   if (authMethod == TorSettings::PasswordAuth
         && ui.linePassword->text().isEmpty()
@@ -176,13 +176,13 @@ AdvancedPage::save(QString &errmsg)
 
   /* Only remember the torrc and datadir values if Vidalia started Tor, or
    * if the user changed the displayed values. */
-  if (Vidalia::torControl()->isVidaliaRunningTor() or 
+  if (Vidalia::torControl()->isVidaliaRunningTor() or
       !Vidalia::torControl()->isConnected()) {
     QString torrc = ui.lineTorConfig->text();
     if (torrc != _settings->getTorrc()) {
       _settings->setTorrc(torrc);
       if(Vidalia::torControl()->isConnected()) {
-        QMessageBox::StandardButtons res = QMessageBox::question(this, tr("Warning"), 
+        QMessageBox::StandardButtons res = QMessageBox::question(this, tr("Warning"),
             tr("You changed torrc path, would you like to restart Tor?"),
             QMessageBox::Yes | QMessageBox::No);
         if(res == QMessageBox::Yes)
@@ -198,6 +198,7 @@ AdvancedPage::save(QString &errmsg)
   if(!ui.chkAuto->isChecked()) {
     _settings->setControlAddress(controlAddress);
     _settings->setControlPort(ui.lineControlPort->text().toUShort());
+    _settings->setAutoControlPort(false);
   }
   _settings->setSocketPath(ui.lineSocketPath->text());
 
@@ -290,7 +291,7 @@ void
 AdvancedPage::browseTorConfig()
 {
   /* Prompt the user to select a file or create a new one */
-  QString filename = QFileDialog::getOpenFileName(this, 
+  QString filename = QFileDialog::getOpenFileName(this,
                        tr("Select Tor Configuration File"),
                        QFileInfo(ui.lineTorConfig->text()).filePath(),
                        tr("Tor Configuration File (torrc);;All Files (*)"));
@@ -309,7 +310,7 @@ AdvancedPage::browseTorConfig()
                      tr("%1 does not exist. Would you like to create it?")
                                                             .arg(filename),
                      VMessageBox::Yes, VMessageBox::No);
-    
+
     if (response == VMessageBox::No) {
       /* Don't create it. Just bail. */
       return;
@@ -325,7 +326,7 @@ AdvancedPage::browseTorConfig()
       return;
     }
   }
-  ui.lineTorConfig->setText(filename);
+  ui.lineTorConfig->setText(QDir::toNativeSeparators(filename));
 }
 
 /** Opens a QFileDialog for the user to browse to or create a directory for
@@ -337,8 +338,8 @@ AdvancedPage::browseTorDataDirectory()
                       tr("Select a Directory to Use for Tor Data"),
                       ui.lineTorDataDirectory->text());
 
-  if (!dataDir.isEmpty()) 
-    ui.lineTorDataDirectory->setText(dataDir);
+  if (!dataDir.isEmpty())
+    ui.lineTorDataDirectory->setText(QDir::toNativeSeparators(dataDir));
 }
 
 /** Opens a QFileDialog for the user to browse to or create a socket path to
@@ -353,7 +354,7 @@ AdvancedPage::browseSocketPath()
                       tr("Select a file to use for Tor socket path"),
                       start);
 
-  if (!socketPath.isEmpty()) 
+  if (!socketPath.isEmpty())
     ui.lineSocketPath->setText(socketPath);
 }
 
@@ -369,12 +370,12 @@ AdvancedPage::setupService(bool useService)
   if (!useService && isInstalled) {
     /* Uninstall if we don't want to use it anymore */
     Vidalia::torControl()->stop();
-    
+
     if (!service.remove()) {
       VMessageBox::critical(this,
                             tr("Unable to remove Tor Service"),
                             tr("Vidalia was unable to remove the Tor service.\n\n"
-                               "You may need to remove it manually."), 
+                               "You may need to remove it manually."),
                             VMessageBox::Ok, VMessageBox::Cancel);
     }
   } else if (useService && !isInstalled) {
@@ -393,14 +394,14 @@ AdvancedPage::setupService(bool useService)
 #endif
 
 /** Called when the user presses the Edit current torrc button */
-void 
+void
 AdvancedPage::displayTorrcDialog()
 {
   TorrcDialog rcdialog(this);
   rcdialog.exec();
 }
 
-void 
+void
 AdvancedPage::toggleControl(bool)
 {
   if(ui.rdoControlPort->isChecked()) {
