@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -17,7 +17,6 @@
 #include "NetworkSettings.h"
 #include "VMessageBox.h"
 #include "Vidalia.h"
-#include "BridgeDownloaderProgressDialog.h"
 #include "DomainValidator.h"
 
 #include "stringutil.h"
@@ -41,7 +40,7 @@ NetworkPage::NetworkPage(QWidget *parent)
 
   connect(ui.btnAddBridge, SIGNAL(clicked()), this, SLOT(addBridge()));
   connect(ui.btnRemoveBridge, SIGNAL(clicked()), this, SLOT(removeBridge()));
-  connect(ui.btnCopyBridge, SIGNAL(clicked()), 
+  connect(ui.btnCopyBridge, SIGNAL(clicked()),
           this, SLOT(copySelectedBridgesToClipboard()));
   connect(ui.listBridges, SIGNAL(customContextMenuRequested(QPoint)),
           this, SLOT(bridgeContextMenuRequested(QPoint)));
@@ -50,7 +49,6 @@ NetworkPage::NetworkPage(QWidget *parent)
   connect(ui.lineBridge, SIGNAL(returnPressed()), this, SLOT(addBridge()));
   connect(ui.lblHelpFindBridges, SIGNAL(linkActivated(QString)),
           this, SLOT(onLinkActivated(QString)));
-  connect(ui.btnFindBridges, SIGNAL(clicked()), this, SLOT(findBridges()));
   connect(ui.cmboProxyType, SIGNAL(currentIndexChanged(int)),
           this, SLOT(proxyTypeChanged(int)));
 
@@ -61,17 +59,6 @@ NetworkPage::NetworkPage(QWidget *parent)
                        ui.listBridges, this,
                        SLOT(copySelectedBridgesToClipboard()));
 
-  if (! BridgeDownloader::isMethodSupported(BridgeDownloader::DownloadMethodHttps)) {
-    ui.btnFindBridges->setVisible(false);
-    ui.lblHelpFindBridges->setText(
-      tr("<a href=\"bridges.finding\">How can I find bridges?</a>"));
-    _bridgeDownloader = 0;
-  } else {
-    _bridgeDownloader = new BridgeDownloader(this);
-    connect(_bridgeDownloader, SIGNAL(bridgeRequestFinished(QStringList)),
-            this, SLOT(bridgeRequestFinished(QStringList)));
-  }
-
 #if defined(Q_WS_MAC)
   /* On OS X, the network page looks better without frame titles. Everywhere
    * else needs titles or else there's a break in the frame border. */
@@ -122,74 +109,18 @@ NetworkPage::onLinkActivated(const QString &url)
   emit helpRequested(url);
 }
 
-/** Verifies that <b>bridge</b> is a valid bridge identifier and places a 
- * normalized identifier in <b>out</b>. The normalized identifier will have
- * all spaces removed from the fingerprint portion (if any) and all
- * hexadecimal characters converted to uppercase. Returns true if
- * <b>bridge</b> is a valid bridge identifier, false otherwise. */
-bool
-NetworkPage::validateBridge(const QString &bridge, QString *out)
-{
-  QString temp = bridge;
-  if (temp.startsWith("bridge ", Qt::CaseInsensitive))
-    temp = temp.remove(0, 7); /* remove "bridge " */
-
-  QStringList parts = temp.split(" ", QString::SkipEmptyParts);
-  if (parts.isEmpty())
-    return false;
-
-  QString s = parts.at(0);
-  QRegExp re("(\\d{1,3}\\.){3}\\d{1,3}(:\\d{1,5})?");
-  if (re.exactMatch(s)) {
-    if (s.endsWith(":"))
-      return false;
-
-    int index = s.indexOf(":");
-    QString host = s.mid(0, index);
-    if (QHostAddress(host).isNull()
-          || QHostAddress(host).protocol() != QAbstractSocket::IPv4Protocol) {
-      return false;
-    }
-    if (index > 0) {
-      QString port = s.mid(index + 1);
-      if (port.toUInt() < 1 || port.toUInt() > 65535)
-        return false;
-    }
-
-    temp = s;
-    if (parts.size() > 1) {
-      QString fp = static_cast<QStringList>(parts.mid(1)).join("");
-      if (fp.length() != 40 || !string_is_hex(fp))
-        return false;
-      temp += " " + fp.toUpper();
-    }
-  } else {
-    return false;
-  }
-  *out = temp;
-  return true;
-}
-
 /** Adds a bridge to the bridge list box. */
 void
 NetworkPage::addBridge()
 {
-  QString bridge;
   QString input = ui.lineBridge->text().trimmed();
 
   if (input.isEmpty())
     return;
-  if (!validateBridge(input, &bridge)) {
-    VMessageBox::warning(this,
-                  tr("Invalid Bridge"),
-                  tr("The specified bridge identifier is not valid."),
-                  VMessageBox::Ok|VMessageBox::Default);
-    return;
-  }
-  if (!ui.listBridges->findItems(bridge, Qt::MatchFixedString).isEmpty())
+  if (!ui.listBridges->findItems(input, Qt::MatchFixedString).isEmpty())
     return; /* duplicate bridge */
 
-  ui.listBridges->addItem(bridge);
+  ui.listBridges->addItem(input);
   ui.lineBridge->clear();
 }
 
@@ -223,11 +154,11 @@ void
 NetworkPage::bridgeContextMenuRequested(const QPoint &pos)
 {
   QMenu menu(this);
-  
+
   QListWidgetItem *item = ui.listBridges->itemAt(pos);
   if (!item)
     return;
-  
+
   QAction *copyAction =
     new QAction(QIcon(IMG_COPY), tr("Copy (Ctrl+C)"), &menu);
   connect(copyAction, SIGNAL(triggered()),
@@ -257,7 +188,7 @@ NetworkPage::save(QString &errmsg)
   QStringList bridgeList;
   QList<quint16> reachablePorts;
   bool ok;
-  
+
   if (ui.chkUseProxy->isChecked()) {
     if (ui.lineProxyAddress->text().isEmpty()
           || ui.lineProxyPort->text().isEmpty()) {
@@ -287,7 +218,7 @@ NetworkPage::save(QString &errmsg)
 
     user = ui.lineProxyUsername->text();
     pass = ui.lineProxyPassword->text();
- 
+
     QVariant data;
     int type;
 
@@ -303,7 +234,7 @@ NetworkPage::save(QString &errmsg)
   settings.setProxyAddress(addr);
   settings.setProxyUsername(user);
   settings.setProxyPassword(pass);
- 
+
   /* Save the reachable port settings */
   settings.setFascistFirewall(ui.chkFascistFirewall->isChecked());
   foreach (QString portString,
@@ -317,6 +248,13 @@ NetworkPage::save(QString &errmsg)
   }
   settings.setReachablePorts(reachablePorts);
 
+  if (ui.chkUseBridges->isChecked()) {
+    if (ui.listBridges->count() < 1) {
+      errmsg = tr("You must specify one or more bridges.");
+      return false;
+    }
+  }
+
   /* Save the bridge settings */
   settings.setUseBridges(ui.chkUseBridges->isChecked());
   for (int i = 0; i < ui.listBridges->count(); i++)
@@ -359,7 +297,6 @@ NetworkPage::load()
     proxyType = NetworkSettings::NoProxy;
     ui.chkUseProxy->setChecked(false);
   }
-  ui.cmboProxyType->addItem(tr("HTTP"), NetworkSettings::HttpProxy);
   ui.cmboProxyType->addItem(tr("HTTP / HTTPS"),
                             NetworkSettings::HttpHttpsProxy);
 
@@ -374,93 +311,11 @@ NetworkPage::load()
   ui.lineReachablePorts->setText(reachablePortStrings.join(","));
 
   /* Load bridge settings */
-  ui.chkUseBridges->setChecked(settings.getUseBridges()); 
+  ui.chkUseBridges->setChecked(settings.getUseBridges());
   ui.listBridges->clear();
   ui.listBridges->addItems(settings.getBridgeList());
 }
 
-/** Called when the user clicks the "Find Bridges Now" button.
- * Attempts to establish an HTTPS connection to bridges.torproject.org
- * and download one or more bridge addresses. */
-void
-NetworkPage::findBridges()
-{
-  BridgeDownloaderProgressDialog *dlg = new BridgeDownloaderProgressDialog(this);
-
-  connect(_bridgeDownloader, SIGNAL(statusChanged(QString)),
-          dlg, SLOT(setStatus(QString)));
-  connect(_bridgeDownloader, SIGNAL(downloadProgress(int, int)),
-          dlg, SLOT(setDownloadProgress(int, int)));
-  connect(_bridgeDownloader, SIGNAL(bridgeRequestFailed(QString)),
-          dlg, SLOT(bridgeRequestFailed(QString)));
-  connect(_bridgeDownloader, SIGNAL(bridgeRequestFinished(QStringList)),
-          dlg, SLOT(bridgeRequestFinished(QStringList)));
-  connect(dlg, SIGNAL(retry()), this, SLOT(startBridgeRequest()));
-
-  startBridgeRequest();
-  switch (dlg->exec()) {
-    case QDialogButtonBox::Cancel:
-      _bridgeDownloader->cancelBridgeRequest();
-      break;
-
-    case QDialogButtonBox::Help:
-      emit helpRequested("bridges.finding");
-      break;
-  }
-
-  delete dlg;
-}
-
-/** Starts a new request for additional bridge addresses. */
-void
-NetworkPage::startBridgeRequest()
-{ 
-  if (ui.chkUseProxy->isChecked() &&
-     ui.cmboProxyType->currentIndex() == NetworkSettings::HttpHttpsProxy) {
-    _bridgeDownloader->setProxy(ui.lineProxyAddress->text(),
-                                ui.lineProxyPort->text().toUInt(),
-                                ui.lineProxyUsername->text(),
-                                ui.lineProxyPassword->text());
-  }
-
-  _bridgeDownloader->downloadBridges(BridgeDownloader::DownloadMethodHttps);
-}
-
-/** Called when a previous bridge request initiated by the findBridges()
- * method has completed. <b>bridges</b> contains a list of all bridges
- * received. */
-void
-NetworkPage::bridgeRequestFinished(const QStringList &bridges)
-{
-  bool foundNewBridges = false;
-  QString normalized;
-
-  foreach (QString bridge, bridges) {
-    if (! validateBridge(bridge, &normalized))
-      continue;
-
-    QString address = normalized.split(" ").at(0);
-    if (ui.listBridges->findItems(address, Qt::MatchContains).isEmpty()) {
-      ui.listBridges->addItem(normalized);
-      foundNewBridges = true;
-    }
-  }
-
-  if (! foundNewBridges) {
-    QMessageBox dlg(this);
-    dlg.setIcon(QMessageBox::Information);
-    dlg.setText(tr("No new bridges are currently available. You can either "
-                   "wait a while and try again, or try another method of "
-                   "finding new bridges."));
-    dlg.setInformativeText(tr("Click Help to see other methods of finding "
-                              "new bridges."));
-    dlg.setStandardButtons(QMessageBox::Ok | QMessageBox::Help);
- 
-    if (dlg.exec() == QMessageBox::Help)
-      emit helpRequested("bridges.finding");      
-  }
-}
-
 /** Disable proxy username and password fields when the user wants to use
  * a SOCKS 4 proxy. */
 void
