@@ -3,8 +3,8 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
-**  including this file, may be copied, modified, propagated, or distributed 
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
 **  except according to the terms described in the LICENSE file.
 */
 
@@ -12,7 +12,7 @@
 ** \file TorrcDialog.cpp
 ** \brief Torrc Dialog, contains the dialog for displaying and editing the torrc
 **
-** Implements the dialog for editing the torrc file inside Vidalia 
+** Implements the dialog for editing the torrc file inside Vidalia
 */
 
 #include "TorrcDialog.h"
@@ -61,12 +61,12 @@ TorrcDialog::~TorrcDialog()
 
 }
 
-/** Gives a shallow parse phase to the settings to catch most errors 
+/** Gives a shallow parse phase to the settings to catch most errors
  * and passes on the error messages from Tor if the setting's value isn't
  * valid. It returns false if something went wrong.
- * If there's a problem in the setting stage, changes to that point will 
+ * If there's a problem in the setting stage, changes to that point will
  * remaind but won't be saved. */
-bool 
+bool
 TorrcDialog::parseAndSet(QString *errmsg)
 {
   if(!errmsg) errmsg = new QString("");
@@ -77,7 +77,7 @@ TorrcDialog::parseAndSet(QString *errmsg)
 
   QString key, val;
   QStringList parts, lines;
-  
+
   if(ui.rdoAll->isChecked())
     lines = ui.teditTorrc->toPlainText().split('\n', QString::SkipEmptyParts);
   else {
@@ -97,6 +97,10 @@ TorrcDialog::parseAndSet(QString *errmsg)
   int i = 0;
   foreach(QString line, lines) {
     i++;
+    int commentIndex = line.indexOf("#");
+    if(commentIndex != -1)
+      line = line.remove(commentIndex, line.length() - commentIndex);
+
     line = line.trimmed();
     if(line.startsWith("#")) continue; // Skip commentaries
     parts = line.split(" ", QString::SkipEmptyParts);
@@ -123,7 +127,7 @@ TorrcDialog::parseAndSet(QString *errmsg)
 
 /** Loads the saved torrc file that Tor's using to the TextEdit widget for
  * editing */
-void 
+void
 TorrcDialog::loadTorrc()
 {
   if(tc && tc->isConnected()) {
@@ -145,7 +149,7 @@ TorrcDialog::loadTorrc()
 
 /** Calls the parsing and setting routine, and if everything went right
  * it saves the configuration to the torrc file through the SAVECONF control */
-void 
+void
 TorrcDialog::saveTorrc()
 {
   QString errmsg = "";
