@@ -3,8 +3,8 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
-**  including this file, may be copied, modified, propagated, or distributed 
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
 **  except according to the terms described in the LICENSE file.
 */
 
@@ -29,8 +29,12 @@
 #define SETTING_RUN_TOR_AT_START    "RunTorAtStart"
 #define SETTING_DATA_DIRECTORY      "DataDirectory"
 #define SETTING_SHOW_MAINWINDOW_AT_START  "ShowMainWindowAtStart"
-#define SETTING_BROWSER_EXECUTABLE  "BrowserExecutable"
-#define SETTING_BROWSER_DIRECTORY   "BrowserDirectory"
+#define SETTING_BROWSER_EXECUTABLE        "BrowserExecutable"
+#define SETTING_BROWSER_DIRECTORY         "BrowserDirectory"
+#define SETTING_PROFILE_DIRECTORY          "ProfileDirectory"
+#define SETTING_DEFAULT_PROFILE_DIRECTORY  "DefaultProfileDirectory"
+#define SETTING_PLUGINS_DIRECTORY          "PluginsDirectory"
+#define SETTING_DEFAULT_PLUGINS_DIRECTORY  "DefaultPluginsDirectory"
 #define SETTING_IM_EXECUTABLE       "IMExecutable"
 #define SETTING_RUN_PROXY_AT_START  "RunProxyAtStart"
 #define SETTING_PROXY_EXECUTABLE    "ProxyExecutable"
@@ -39,13 +43,14 @@
 #define SETTING_LAST_UPDATE_CHECK   "LastUpdateCheck"
 #define SETTING_USE_LOCAL_GEOIP_DATABASE  "UseLocalGeoIpDatabase"
 #define SETTING_LOCAL_GEOIP_DATABASE "LocalGeoIpDatabase"
+#define SETTING_SKIP_VERSION_CHECK  "SkipVersionCheck"
 
 #if defined(Q_OS_WIN32)
 #define STARTUP_REG_KEY        "Software\\Microsoft\\Windows\\CurrentVersion\\Run"
-#define VIDALIA_REG_KEY        "Vidalia" 
+#define VIDALIA_REG_KEY        "Vidalia"
 #endif
 
-#define SETTING_ICON_PREF	"IconDisplayPreference"
+#define SETTING_ICON_PREF  "IconDisplayPreference"
 
 /** Default Constructor */
 VidaliaSettings::VidaliaSettings()
@@ -84,6 +89,12 @@ VidaliaSettings::VidaliaSettings()
   setDefault(SETTING_USE_LOCAL_GEOIP_DATABASE, false);
   setDefault(SETTING_LOCAL_GEOIP_DATABASE, "");
   setDefault(SETTING_ICON_PREF, Both);
+  setDefault(SETTING_SKIP_VERSION_CHECK, false);
+
+  setDefault(SETTING_PROFILE_DIRECTORY, "");
+  setDefault(SETTING_DEFAULT_PROFILE_DIRECTORY, "");
+  setDefault(SETTING_PLUGINS_DIRECTORY, "");
+  setDefault(SETTING_DEFAULT_PLUGINS_DIRECTORY, "");
 }
 
 /** Gets the currently preferred language code for Vidalia. */
@@ -355,3 +366,57 @@ VidaliaSettings::fromString(QString iconPref)
 
   return Both;
 }
+
+bool
+VidaliaSettings::skipVersionCheck() const
+{
+  return value(SETTING_SKIP_VERSION_CHECK).toBool();
+}
+
+QString
+VidaliaSettings::getDefaultProfileDirectory() const
+{
+  return QDir::convertSeparators(value(SETTING_DEFAULT_PROFILE_DIRECTORY).toString());
+}
+
+void
+VidaliaSettings::setDefaultProfileDirectory(const QString &dir)
+{
+  setValue(SETTING_DEFAULT_PROFILE_DIRECTORY, dir);
+}
+
+QString
+VidaliaSettings::getProfileDirectory() const
+{
+  return QDir::convertSeparators(value(SETTING_PROFILE_DIRECTORY).toString());
+}
+
+void
+VidaliaSettings::setProfileDirectory(const QString &dir)
+{
+  setValue(SETTING_PROFILE_DIRECTORY, dir);
+}
+
+QString
+VidaliaSettings::getPluginsDirectory() const
+{
+  return QDir::convertSeparators(value(SETTING_PLUGINS_DIRECTORY).toString());
+}
+
+void
+VidaliaSettings::setPluginsDirectory(const QString &dir)
+{
+  setValue(SETTING_PLUGINS_DIRECTORY, dir);
+}
+
+QString
+VidaliaSettings::getDefaultPluginsDirectory() const
+{
+  return QDir::convertSeparators(value(SETTING_DEFAULT_PLUGINS_DIRECTORY).toString());
+}
+
+void
+VidaliaSettings::setDefaultPluginsDirectory(const QString &dir)
+{
+  setValue(SETTING_DEFAULT_PLUGINS_DIRECTORY, dir);
+}
