@@ -3,8 +3,8 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
-**  including this file, may be copied, modified, propagated, or distributed 
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia,
+**  including this file, may be copied, modified, propagated, or distributed
 **  except according to the terms described in the LICENSE file.
 */
 
@@ -46,12 +46,12 @@ public:
   QString getLanguageCode();
   /** Saves the preferred language code. */
   void setLanguageCode(QString languageCode);
- 
+
   /** Gets the interface style key (e.g., "windows", "motif", etc.) */
   QString getInterfaceStyle();
   /** Sets the interface style key. */
   void setInterfaceStyle(QString styleKey);
-  
+
   /** Returns true if Vidalia should start Tor when it starts. */
   bool runTorAtStart();
   /** Set whether to run Tor when Vidalia starts. */
@@ -62,7 +62,7 @@ public:
   bool showMainWindowAtStart();
   /** Sets whether to show Vidalia's main window when the application starts. */
   void setShowMainWindowAtStart(bool show);
-  
+
   /** Returns true if Vidalia should start on system boot. */
   bool runVidaliaOnBoot();
   /** Set whether to run Vidalia on system boot. */
@@ -82,6 +82,16 @@ public:
    * If set to the empty string, the browser will not be started. */
   void setBrowserDirectory(const QString &browserDirectory);
 
+  /** Browser directories */
+  QString getDefaultProfileDirectory() const;
+  void setDefaultProfileDirectory(const QString &dir);
+  QString getProfileDirectory() const;
+  void setProfileDirectory(const QString &dir);
+  QString getPluginsDirectory() const;
+  void setPluginsDirectory(const QString &dir);
+  QString getDefaultPluginsDirectory() const;
+  void setDefaultPluginsDirectory(const QString &dir);
+
   /** Returns a fully-qualified path to the IM client, including the
    * executable name. */
   QString getIMExecutable() const;
@@ -107,7 +117,7 @@ public:
   QString getProxyExecutableArguments() const;
   /** Sets the additional arguments to be passed to Proxy Executable */
   void setProxyExecutableArguments(const QString &proxyExecutableArguments);
-  
+
   /** Returns true if Vidalia should automatically check for software updates.
    */
   bool isAutoUpdateEnabled() const;
@@ -139,6 +149,9 @@ public:
   void setIconPref(const IconPosition iconPref);
   QString toString(const IconPosition iconPref);
   IconPosition fromString(QString iconPref);
+
+  /** Returns true if Vidalia should skip the version check for tor */
+  bool skipVersionCheck() const;
 };
 
 #endif
